@@ -2,9 +2,10 @@
 # See the LICENSE file for the full license.
 
 class APIError(Exception):
-	def __init__(self, code, description):
+	def __init__(self, code, description, body = None):
 		self.code = code
 		self.description = description
+		self.body = body
 	
 	def __str__(self):
 		return "#%i: %s" % (self.code, self.description)
